.. module:: enaml.colors

============
enaml.colors
============

.. rubric:: Functions

.. autosummary::
    :nosignatures:

    parse_color


.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Color
    ColorMember


.. autofunction:: parse_color

.. autoclass:: Color
